// Copyright (C) 2021  Simon Ruderich
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package sync

import (
	"testing"

	"ruderich.org/simon/safcm/testutil"
)

func TestTriggerPaths(t *testing.T) {
	tests := []struct {
		name string
		path string
		exp  []string
	}{

		{
			"root",
			"/",
			[]string{"/"},
		},

		{
			"absolute path",
			"/foo/bar/baz",
			[]string{"/", "/foo", "/foo/bar", "/foo/bar/baz"},
		},

		{
			"dot",
			".",
			[]string{"."},
		},

		{
			"relative path (for tests)",
			"foo/bar/baz",
			[]string{".", "foo", "foo/bar", "foo/bar/baz"},
		},
	}

	for _, tc := range tests {
		t.Run(tc.name, func(t *testing.T) {
			res := triggerPaths(tc.path)
			testutil.AssertEqual(t, "res", res, tc.exp)
		})
	}
}
